summary refs log tree commit diff
path: root/arch/ia64
diff options
context:
space:
mode:
authorJiri Slaby <jslaby@suse.cz>2012-03-05 14:52:26 +0100
committerGreg Kroah-Hartman <gregkh@linuxfoundation.org>2012-03-08 12:30:51 -0800
commit12c8035435fa16e3f6b18049bb1d7815c00a7a58 (patch)
tree4777a85e7f4902bc37b1ace6d26e11d2ec43fb1b /arch/ia64
parent799be6ff2fd7294f428a9e68a7786490c862c1af (diff)
downloadlinux-12c8035435fa16e3f6b18049bb1d7815c00a7a58.tar.gz
TTY: amiserial/simserial, use count from tty_port
Nothing special. Just remove count from serial_state and change all
users to use tty_port.

Signed-off-by: Jiri Slaby <jslaby@suse.cz>
Cc: Geert Uytterhoeven <geert@linux-m68k.org>
Cc: Tony Luck <tony.luck@intel.com>
Cc: Fenghua Yu <fenghua.yu@intel.com>
Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>
Diffstat (limited to 'arch/ia64')
-rw-r--r--arch/ia64/hp/sim/simserial.c24
1 files changed, 12 insertions, 12 deletions
diff --git a/arch/ia64/hp/sim/simserial.c b/arch/ia64/hp/sim/simserial.c
index fb324b345e88..baa2b1ec00a0 100644
--- a/arch/ia64/hp/sim/simserial.c
+++ b/arch/ia64/hp/sim/simserial.c
@@ -500,26 +500,26 @@ static void rs_close(struct tty_struct *tty, struct file * filp)
 		return;
 	}
 #ifdef SIMSERIAL_DEBUG
-	printk("rs_close ttys%d, count = %d\n", info->line, info->count);
+	printk("rs_close ttys%d, count = %d\n", info->line, info->tport.count);
 #endif
-	if ((tty->count == 1) && (info->count != 1)) {
+	if ((tty->count == 1) && (info->tport.count != 1)) {
 		/*
 		 * Uh, oh.  tty->count is 1, which means that the tty
 		 * structure will be freed.  info->count should always
 		 * be one in these conditions.  If it's greater than
 		 * one, we've got real problems, since it means the
 		 * serial port won't be shutdown.
 		 */
 		printk(KERN_ERR "rs_close: bad serial port count; tty->count is 1, "
-		       "info->count is %d\n", info->count);
-		info->count = 1;
+		       "info->tport.count is %d\n", info->tport.count);
+		info->tport.count = 1;
 	}
-	if (--info->count < 0) {
+	if (--info->tport.count < 0) {
 		printk(KERN_ERR "rs_close: bad serial port count for ttys%d: %d\n",
-		       info->line, info->count);
-		info->count = 0;
+		       info->line, info->tport.count);
+		info->tport.count = 0;
 	}
-	if (info->count) {
+	if (info->tport.count) {
 		local_irq_restore(flags);
 		return;
 	}
@@ -567,7 +567,7 @@ static void rs_hangup(struct tty_struct *tty)
 		return;
 	shutdown(tty, info);
 
-	info->count = 0;
+	info->tport.count = 0;
 	info->flags &= ~ASYNC_NORMAL_ACTIVE;
 	info->tport.tty = NULL;
 	wake_up_interruptible(&info->tport.open_wait);
@@ -661,13 +661,13 @@ static int rs_open(struct tty_struct *tty, struct file * filp)
 	int			retval;
 	unsigned long		page;
 
-	info->count++;
+	info->tport.count++;
 	info->tport.tty = tty;
 	tty->driver_data = info;
 	tty->port = &info->tport;
 
 #ifdef SIMSERIAL_DEBUG
-	printk("rs_open %s, count = %d\n", tty->name, info->count);
+	printk("rs_open %s, count = %d\n", tty->name, info->tport.count);
 #endif
 	tty->low_latency = (info->flags & ASYNC_LOW_LATENCY) ? 1 : 0;
@@ -500,26 +500,26 @@ static void rs_close(struct tty_struct *tty, struct file * filp)
 		/*
 		 * Uh, oh.  tty->count is 1, which means that the tty
-		 * structure will be freed.  info->count should always
+		 * structure will be freed.  info->tport.count should always
 		 * be one in these conditions.  If it's greater than
 		 * one, we've got real problems, since it means the